/**
 * The hash formats allowed by Packwiz.
 */
export enum HashFormat {
  "sha256" = "sha256",
  "sha512" = "sha512",
  "sha1" = "sha1",
  "md5" = "md5",
  "murmur2" = "murmur2",
}

/**
 * Checks if the provided hash format is allowed by Packwiz.
 * @param hashFormat - The hash format to check.
 * @returns The HashFormat enum value if valid, otherwise throws an error.
 */
export function isValidHashFormat(hashFormat: string): HashFormat {
  if (hashFormat in HashFormat) {
    return HashFormat[hashFormat as keyof typeof HashFormat];
  } else {
    throw new Error(`Invalid index file hash format: ${hashFormat}`);
  }
}
